package com.jjt.emp.service;

import java.util.Date;
import java.util.List;
import com.jjt.emp.domain.TwinEmp;

/**
 * 员工排班Service接口
 *
 * @author wukai
 * @date 2025-01-18
 */
public interface ITwinEmpService {
    /**
     * 查询员工排班
     *
     * @param empId 员工排班主键
     * @return 员工排班
     */
    public TwinEmp selectTwinEmpByEmpId(Long empId);

    /**
     * 查询员工排班列表
     *
     * @param twinEmp 员工排班
     * @return 员工排班集合
     */
    public List<TwinEmp> selectTwinEmpList(TwinEmp twinEmp);

    /**
     * 新增员工排班
     *
     * @param twinEmp 员工排班
     * @return 结果
     */
    public int insertTwinEmp(TwinEmp twinEmp);

    /**
     * 修改员工排班
     *
     * @param twinEmp 员工排班
     * @return 结果
     */
    public int updateTwinEmp(TwinEmp twinEmp);

    /**
     * 批量删除员工排班
     *
     * @param empIds 需要删除的员工排班主键集合
     * @return 结果
     */
    public int deleteTwinEmpByEmpIds(Long[] empIds);

    /**
     * 删除员工排班信息
     *
     * @param empId 员工排班主键
     * @return 结果
     */
    public int deleteTwinEmpByEmpId(Long empId);
    /**
     * 按日期查询排班
     *
     * @param date 日期
     * @return 排班结果
     */
    TwinEmp selectTwinEmpByDate(Date date);
}
